@@ -1,11 +1,11 @@
 package Cpanel::JSON::XS;
-our $VERSION = '3.0205';
+our $VERSION = '3.0206';
 
 =pod
 
 =head1 NAME
 
-Cpanel::JSON::XS - JSON::XS for Cpanel, fast and correct serialising, also for 5.6.2
+Cpanel::JSON::XS - Cpanel fork of JSON::XS, fast and correct serialising
 
 =head1 SYNOPSIS
 
@@ -107,15 +107,16 @@ or        L<https://rt.cpan.org/Public/Dist/Display.html?Queue=Cpanel-JSON-XS>
 
 B<Changes to JSON::XS>
 
-- stricter decode_json() as documented. non-refs are disallowed. decode() honors now allow_nonref.
+- stricter decode_json() as documented. non-refs are disallowed.
+  added a 2nd optional argument. decode() honors now allow_nonref.
 
 - fixed encode of numbers for dual-vars. Different string representations
   are preserved, but numbers with temporary strings which represent the same number
   are here treated as numbers, not strings. Cpanel::JSON::XS is a bit slower, but
   preserves numeric types better.
 
-- different handling of inf/nan. Default now to null, optionally with -DSTRINGIFY_INFNAN
-  to "inf"/"nan". [#28, #32]
+- different handling of inf/nan. Default now to null, optionally with
+  -DSTRINGIFY_INFNAN to "inf"/"nan". [#28, #32]
 
 - added C<binary> extension, non-JSON and non JSON parsable, allows
   C<\xNN> and C<\NNN> sequences.
@@ -133,6 +134,9 @@ B<Changes to JSON::XS>
   In perl C<!0> is yes, C<!1> is no.
   The JSON value true maps to 1, false maps to 0. [#39]
 
+- support arbitrary stringification with encode, with convert_blessed
+  and allow_blessed.
+
 - ithread support. Cpanel::JSON::XS is thread-safe, JSON::XS not
 
 - is_bool can be called as method, JSON::XS::is_bool not.
@@ -159,6 +163,8 @@ B<Changes to JSON::XS>
 
 - extended testsuite
 
+- support many more options and methods from JSON::PP
+
 
 =cut
 
@@ -358,6 +364,7 @@ in files or databases, not when talking to other JSON encoders/decoders.
   Cpanel::JSON::XS->new->latin1->encode (["\x{89}\x{abc}"]
   => ["\x{89}\\u0abc"]    # (perl syntax, U+abc escaped, U+89 not)
 
+
 =item $json = $json->binary ([$enable])
 
 =item $enabled = $json = $json->get_binary
@@ -409,6 +416,7 @@ non-JSON conformant hex or octal encoding C<\xNN> or C<\NNN>.
   Cpanel::JSON::XS->new->decode (["\x89"])
   Error: illegal hex character in non-binary string
 
+
 =item $json = $json->utf8 ([$enable])
 
 =item $enabled = $json->get_utf8
@@ -456,6 +464,7 @@ Example, pretty-print some simple structure:
       ]
    }
 
+
 =item $json = $json->indent ([$enable])
 
 =item $enabled = $json->get_indent
@@ -469,6 +478,7 @@ resulting JSON text is guaranteed not to contain any C<newlines>.
 
 This setting has no effect when decoding JSON texts.
 
+
 =item $json = $json->space_before ([$enable])
 
 =item $enabled = $json->get_space_before
@@ -560,8 +570,25 @@ substituted for "\t" sequence.
      "Hello<TAB>World", # literal <TAB> would not normally be allowed
   ]
 
+=item * allow_singlequote
+
+Single quotes are accepted instead of double quotes. See the
+L</allow_singlequote> option.
+
+    { "foo":'bar' }
+    { 'foo':"bar" }
+    { 'foo':'bar' }
+
+=item * allow_barekey
+
+Accept unquoted object keys instead of with mandatory double quotes. See the
+L</allow_barekey> option.
+
+    { foo:"bar" }
+
 =back
 
+
 =item $json = $json->canonical ([$enable])
 
 =item $enabled = $json->get_canonical
@@ -583,6 +610,91 @@ This setting has no effect when decoding JSON texts.
 
 This setting has currently no effect on tied hashes.
 
+
+=item $json = $json->sort_by (undef, 0, 1 or a block)
+
+This currently only (un)sets the C<canonical> option, and ignores
+custom sort blocks.
+
+This setting has no effect when decoding JSON texts.
+
+This setting has currently no effect on tied hashes.
+
+
+=item $json = $json->escape_slash ([$enable])
+
+=item $enabled = $json->get_escape_slash
+
+According to the JSON Grammar, the I<forward slash> character (U+002F)
+C<"/"> need to be escaped.  But by default strings are encoded without
+escaping slashes in all perl JSON encoders.
+
+If C<$enable> is true (or missing), then C<encode> will escape slashes,
+C<"\/">.
+
+This setting has no effect when decoding JSON texts.
+
+
+=item $json = $json->allow_singlequote ([$enable])
+
+=item $enabled = $json->get_allow_singlequote
+
+    $json = $json->allow_singlequote([$enable])
+
+If C<$enable> is true (or missing), then C<decode> will accept
+JSON strings quoted by single quotations that are invalid JSON
+format.
+
+    $json->allow_singlequote->decode({"foo":'bar'});
+    $json->allow_singlequote->decode({'foo':"bar"});
+    $json->allow_singlequote->decode({'foo':'bar'});
+
+This is also enabled with C<relaxed>.
+As same as the C<relaxed> option, this option may be used to parse
+application-specific files written by humans.
+
+
+=item $json = $json->allow_barekey ([$enable])
+
+=item $enabled = $json->get_allow_barekey
+
+    $json = $json->allow_barekey([$enable])
+
+If C<$enable> is true (or missing), then C<decode> will accept
+bare keys of JSON object that are invalid JSON format.
+
+Same as with the C<relaxed> option, this option may be used to parse
+application-specific files written by humans.
+
+    $json->allow_barekey->decode('{foo:"bar"}');
+
+
+=item $json = $json->allow_bignum ([$enable])
+
+=item $enabled = $json->get_allow_bignum
+
+    $json = $json->allow_bignum([$enable])
+
+If C<$enable> is true (or missing), then C<decode> will convert
+the big integer Perl cannot handle as integer into a L<Math::BigInt>
+object and convert a floating number (any) into a L<Math::BigFloat>.
+
+On the contary, C<encode> converts C<Math::BigInt> objects and C<Math::BigFloat>
+objects into JSON numbers with C<allow_blessed> enable.
+
+   $json->allow_nonref->allow_blessed->allow_bignum;
+   $bigfloat = $json->decode('2.000000000000000000000000001');
+   print $json->encode($bigfloat);
+   # => 2.000000000000000000000000001
+
+See L<JSON::XS/MAPPING> about the normal conversion of JSON number.
+
+
+=item $json = $json->allow_bigint ([$enable])
+
+This option is obsolete and replaced by allow_bignum.
+
+
 =item $json = $json->allow_nonref ([$enable])
 
 =item $enabled = $json->get_allow_nonref
@@ -1826,6 +1938,10 @@ license and the GPL.
 
 =cut
 
+sub allow_bigint {
+    Carp::carp("allow_bigint() is obsoleted. use allow_bignum() instead.");
+}
+
 our ($true, $false);
 BEGIN {
   if ($INC{'JSON/XS.pm'}
